@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,7 +24,8 @@ QList<TextAddonsWidgets::WhatsNewInfo> WhatsNewTranslations::createWhatsNewInfo(
     {
         TextAddonsWidgets::WhatsNewInfo info;
         QStringList lst;
-        for (const KLazyLocalizedString &l : lastNewFeatures()) {
+        const auto features = lastNewFeatures();
+        for (const KLazyLocalizedString &l : features) {
             lst += l.toString();
         }
         info.setNewFeatures(lst);
